Modules
- synchronous functions
Structs
Constants
- Loading error messaage you get at the first call of
update().
Functions
- Spawns a thread which fetches the current ISS spotting from http://api.open-notify.org periodically.
- Fetch current ISS spotting update once and stop thread immediately after success. Returns the result in a future.
- Get current ISS spotting update that the spawned thread could fetched.
Type Aliases
- Receiver object you get from
init()and have top handle toupdate().